@@ -81,7 +81,12 @@ def _gff_default_parser(gff, fasta, Genes):
             feature = unquote(feature)
             start = int(start)
             end = int(end)
-            ID, Parent, Name, Product, GeneFeature, gbkey = (None,) * 6
+            ID = None
+            Parent = None
+            Name = None
+            Product = None
+            GeneFeature = None
+            gbkey = None
             info = {}
             for field in attributes.split(";"):
                 try:
@@ -93,11 +98,14 @@ def _gff_default_parser(gff, fasta, Genes):
             ID = info.get("ID", None)
             Parent = info.get("Parent", None)
             Name = info.get("Name", None)
-            DBxref = info.get("DBxref", None)
-            if not DBxref and "Dbxref" in info:
-                DBxref = info.get("Dbxref")
-            if not DBxref and "dbxref" in info:
-                DBxref = info.get("dbxref")
+            if "DBxref" in info:
+                DBxref = info.get("DBxref", None)
+            elif "Dbxref" in info:
+                DBxref = info.get("Dbxref", None)
+            elif "dbxref" in info:
+                DBxref = info.get("dbxref", None)
+            else:
+                DBxref = None
             if DBxref:
                 if "," in DBxref:
                     DBxref = DBxref.split(",")
@@ -370,6 +378,10 @@ def _gff_default_parser(gff, fasta, Genes):
                                 # determine which transcript this is get index from id
                                 i = Genes[GeneFeature]["ids"].index(p)
                                 Genes[GeneFeature]["CDS"][i].append((start, end))
+                                if DBxref:
+                                    for dbx in DBxref:
+                                        if not dbx in Genes[GeneFeature]["db_xref"][i]:
+                                            Genes[GeneFeature]["db_xref"][i].append(dbx)
                                 # add phase
                                 try:
                                     Genes[GeneFeature]["phase"][i].append(int(phase))
@@ -535,13 +547,13 @@ def _gff_ncbi_parser(gff, fasta, Genes):
                     pass
             # now can lookup in info dict for values
             ID = info.get("ID", None)
-            if ID and ID.startswith(('gene-', 'exon-', 'rna-', 'cds-')):
-                ID = ID.split('-', 1)[1]
-            Parent = info.get('Parent', None)
-            if Parent and Parent.startswith(('gene-', 'rna-')):
-                Parent = Parent.split('-', 1)[1]
-            Name = info.get('gene', None)
-            if 'DBxref' in info:
+            if ID and ID.startswith(("gene-", "exon-", "rna-", "cds-")):
+                ID = ID.split("-", 1)[1]
+            Parent = info.get("Parent", None)
+            if Parent and Parent.startswith(("gene-", "rna-")):
+                Parent = Parent.split("-", 1)[1]
+            Name = info.get("gene", None)
+            if "DBxref" in info:
                 DBxref = info.get("DBxref", None)
             elif "Dbxref" in info:
                 DBxref = info.get("Dbxref", None)
@@ -1027,6 +1039,8 @@ def validate_and_translate_models(
                         results["partialStart"].append(False)
                     else:
                         results["partialStart"].append(True)
+                    if protSeq.rstrip("*").count("*") > 0:
+                        results["pseudo"] = True
         else:
             results["CDS"].append([])
             results["type"].append(v["type"][i])
@@ -1054,13 +1068,13 @@ def validate_and_translate_models(
 def _detect_format(gff):
     # this is incomplete search, but sniff if this is an NCBI GFF3 record
     parser = _gff_default_parser
-    _format = 'default'
+    _format = "default"
     with zopen(gff) as infile:
         for line in infile:
-            if line.startswith('#'):
-                if '!processor NCBI annotwriter' in line:
+            if line.startswith("#"):
+                if "!processor NCBI annotwriter" in line:
                     parser = _gff_ncbi_parser
-                    _format = 'ncbi'
+                    _format = "ncbi"
             else:
                 break
     return parser, _format
@@ -1070,9 +1084,9 @@ def _clean_ncbi_names(annot):
     Clean = {}
     for k, v in annot.items():
         new_ids = []
-        for i, x in enumerate(v['ids']):
-            new_ids.append('{}-T{}'.format(k, i+1))
-        v['ids'] = new_ids
+        for i, x in enumerate(v["ids"]):
+            new_ids.append("{}-T{}".format(k, i + 1))
+        v["ids"] = new_ids
         Clean[k] = v
     return Clean
 
@@ -1084,6 +1098,7 @@ def gff2dict(
     table=1,
     debug=False,
     gap_filter=False,
+    gff_format="auto",
     logger=sys.stderr.write,
 ):
     """Convert GFF3 and FASTA to standardized GFFtk dictionary format.
@@ -1118,9 +1133,16 @@ def gff2dict(
     if not annotation:
         annotation = {}
     # autodetect format
-    gff_parser, _format = _detect_format(gff)
+    if gff_format == "auto":
+        gff_parser, _format = _detect_format(gff)
+    elif gff_format == "ncbi-euk":
+        gff_parser = _gff_ncbi_parser
+        _format = "ncbi"
+    else:
+        gff_parser = _gff_default_parser
+        _format = "default"
     annotation, parse_errors = gff_parser(gff, fasta, annotation)
-    if _format == 'ncbi':  # clean up identifer names
+    if _format == "ncbi":  # clean up identifer names
         annotation = _clean_ncbi_names(annotation)
     if debug:
         for err, err_v in parse_errors.items():
@@ -1187,7 +1209,9 @@ def gff2dict(
             "product",
         ]:
             if len(annotation[gene]["ids"]) != len(annotation[gene][z]):
-                assert_lengths_fail.append((z, annotation[gene][z], len(annotation[gene][z])))
+                assert_lengths_fail.append(
+                    (z, annotation[gene][z], len(annotation[gene][z]))
+                )
         if len(assert_lengths_fail) > 0:
             logger(
                 "ERROR in parsing gene {}\n{}\n{}\n".format(
@@ -1237,12 +1261,17 @@ def dict2gff3(input, output=False, debug=False):
         gffout = sys.stdout
     gffout.write("##gff-version 3\n")
     for k, v in list(sortedGenes.items()):
+        genefeature = "gene"
+        if "pseudo" in v:
+            if v["pseudo"]:
+                genefeature = "pseudogene"
         if v["name"]:
             if "gene_synonym" in v and len(v["gene_synonym"]) > 0:
                 gffout.write(
-                    "{:}\t{:}\tgene\t{:}\t{:}\t.\t{:}\t.\tID={:};Name={:};Alias={:};\n".format(
+                    "{:}\t{:}\t{:}\t{:}\t{:}\t.\t{:}\t.\tID={:};Name={:};Alias={:};\n".format(
                         v["contig"],
                         v["source"],
+                        genefeature,
                         v["location"][0],
                         v["location"][1],
                         v["strand"],
@@ -1253,9 +1282,10 @@ def dict2gff3(input, output=False, debug=False):
                 )
             else:
                 gffout.write(
-                    "{:}\t{:}\tgene\t{:}\t{:}\t.\t{:}\t.\tID={:};Name={:};\n".format(
+                    "{:}\t{:}\t{:}\t{:}\t{:}\t.\t{:}\t.\tID={:};Name={:};\n".format(
                         v["contig"],
                         v["source"],
+                        genefeature,
                         v["location"][0],
                         v["location"][1],
                         v["strand"],
@@ -1266,9 +1296,10 @@ def dict2gff3(input, output=False, debug=False):
         else:
             if "gene_synonym" in v and len(v["gene_synonym"]) > 0:
                 gffout.write(
-                    "{:}\t{:}\tgene\t{:}\t{:}\t.\t{:}\t.\tID={:};Alias={:};\n".format(
+                    "{:}\t{:}\t{:}\t{:}\t{:}\t.\t{:}\t.\tID={:};Alias={:};\n".format(
                         v["contig"],
                         v["source"],
+                        genefeature,
                         v["location"][0],
                         v["location"][1],
                         v["strand"],
@@ -1278,9 +1309,10 @@ def dict2gff3(input, output=False, debug=False):
                 )
             else:
                 gffout.write(
-                    "{:}\t{:}\tgene\t{:}\t{:}\t.\t{:}\t.\tID={:};\n".format(
+                    "{:}\t{:}\t{:}\t{:}\t{:}\t.\t{:}\t.\tID={:};\n".format(
                         v["contig"],
                         v["source"],
+                        genefeature,
                         v["location"][0],
                         v["location"][1],
                         v["strand"],
@@ -1292,7 +1324,7 @@ def dict2gff3(input, output=False, debug=False):
             # make sure coordinates are sorted
             if v["strand"] == "+":
                 sortedExons = sorted(v["mRNA"][i], key=lambda tup: tup[0])
-                if v['type'][i] == 'mRNA':
+                if v["type"][i] == "mRNA":
                     sortedCDS = sorted(v["CDS"][i], key=lambda tup: tup[0])
                 if "5UTR" in v and v["5UTR"][i]:
                     sortedFive = sorted(v["5UTR"][i], key=lambda tup: tup[0])
@@ -1300,8 +1332,10 @@ def dict2gff3(input, output=False, debug=False):
                     sortedThree = sorted(v["3UTR"][i], key=lambda tup: tup[0])
             else:
                 sortedExons = sorted(v["mRNA"][i], key=lambda tup: tup[0], reverse=True)
-                if v['type'][i] == 'mRNA':
-                    sortedCDS = sorted(v["CDS"][i], key=lambda tup: tup[0], reverse=True)
+                if v["type"][i] == "mRNA":
+                    sortedCDS = sorted(
+                        v["CDS"][i], key=lambda tup: tup[0], reverse=True
+                    )
                 if "5UTR" in v and v["5UTR"][i]:
                     sortedFive = sorted(
                         v["5UTR"][i], key=lambda tup: tup[0], reverse=True
@@ -1417,6 +1451,10 @@ def dict2gff3(input, output=False, debug=False):
                                 )
                             )
             if v["type"][i] == "mRNA":
+                # if a pseudogene do not output CDS
+                if "pseudo" in v:
+                    if v["pseudo"]:
+                        continue
                 num_cds = len(v["CDS"][i])
                 # GFF3 phase is 1 less than flat file
                 current_phase = v["codon_start"][i] - 1
